#
# spec file for package gnome-activity-journal
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2010 Andrew Wafaa, United Kingdom.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnome-activity-journal
Version:        0.8.0
Release:        17.2
Summary:        Chronological journal to help find files
License:        GPL-3.0+ and CC-BY-SA-3.0
Group:          Productivity/File utilities
Url:            http://live.gnome.org/GnomeActivityJournal
Source:         http://launchpad.net/gnome-activity-journal/0.8/0.8.0/+download/%{name}-%{version}.tar.gz
Source99:       gnome-activity-journal-rpmlintrc
# PATCH-FIX-UPSTREAM gaj-zeitgeist09.patch bnc#768577 lp#930196 dimstar@openssue.org -- Fix execution with zeitgeist 0.9
Patch0:         gaj-zeitgeist09.patch
BuildRequires:  fdupes
BuildRequires:  gconf2-devel
# For directory ownership
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  python-devel
BuildRequires:  python-distutils-extra
BuildRequires:  update-desktop-files
BuildRequires:  zeitgeist
Requires:       dbus-1-python
Requires:       python-gconf
# Needed for gnome.ui
Requires:       python-gnome
Requires:       python-gtk
Requires:       zeitgeist
Recommends:     %{name}-lang
# We don't provide gnome-zeitgeist since the binary name has changed
Obsoletes:      gnome-zeitgeist
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %suse_version > 1110
BuildArch:      noarch
%endif
%gconf_schemas_prereq
%py_requires
%if %suse_version <= 1110
%define python_sitelib %{py_sitedir}
%endif

%description
GNOME Activity Journal is a tool for easily browsing and finding files
on your computer. It keeps a chronological journal of all file activity
and supports tagging and establishing relationships between groups of
files.

%lang_package
%prep
%setup -q
%patch0 -p1

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
# Fix for gconf schemas that are not correctly installed
mkdir -p %{buildroot}%{_sysconfdir}/gconf/schemas/
mv %{buildroot}%{_datadir}/gconf/schemas/gnome-activity-journal.schemas %{buildroot}%{_sysconfdir}/gconf/schemas
%suse_update_desktop_file gnome-activity-journal DesktopUtility
%find_lang %{name} %{?no_lang_C}
%find_gconf_schemas
%fdupes %{buildroot}%{py_sitedir}

%pre -f %{name}.schemas_pre

%post
%desktop_database_post
%icon_theme_cache_post

%preun -f %{name}.schemas_preun

%postun
%desktop_database_postun
%icon_theme_cache_postun

%posttrans -f %{name}.schemas_posttrans

%clean
rm -rf %{buildroot}

%files -f %{name}.schemas_list
%defattr(-,root,root)
%doc AUTHORS COPYING README
%{_bindir}/gnome-activity-journal
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/*/*.*
%{_datadir}/gnome-activity-journal/
%{_datadir}/pixmaps/gnome-activity-journal.xpm
%dir %{_datadir}/zeitgeist/_zeitgeist/
%dir %{_datadir}/zeitgeist/_zeitgeist/engine/
%dir %{_datadir}/zeitgeist/_zeitgeist/engine/extensions/
%{_datadir}/zeitgeist/_zeitgeist/engine/extensions/gnome_activity_journal.py
%{python_sitelib}/*.egg-info
%{_mandir}/man?/*.*

%files lang -f %{name}.lang

%changelog
* Wed Mar 20 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Mon Jun 25 2012 dimstar@opensuse.org
- Add gaj-zeitgeist09.patch: Fix execution with zeitgeist 0.9
  (bnc#768577).
* Fri Jun 22 2012 dimstar@opensuse.org
- Fix build by owning our folders.
* Mon Dec 12 2011 coolo@suse.com
- fix license to be in spdx.org format
* Sun Jul 17 2011 dimstar@opensuse.org
- Update to version 0.8.0:
  + Added an incognito mode option to the tray icon.
  + Removed blacklist plugin, replaced by Activity Log Manager.
  + Added different zoom levels to ThumbView and TimelineView.
  + Added an erase mode to easily delete many events.
  + lp#790834: Improved handling of the extension not being
    available
  + lp#715910: Added support for file annotation meta-data
  + Don't show application launch events nor fake events generated
    by Activity Log Manager.
  + lp#643795: Fixed blacklist template deletion
  + Several other minor tweaks (better netbook screen support, etc)
* Thu Jun  9 2011 vuntz@opensuse.org
- Remove gnome-python-desktop Requires: it's not needed at all.
- Add explicit python-gconf Requires as the gconf bindings are
  used.
* Thu May  5 2011 vuntz@opensuse.org
- Update to version 0.6.0:
  + General New features:
  - Added drag and drop support to the three views (lp#553385).
  - Added drag and drop support to the bookmark/pin area
    (lp#365048).
  - Improved items preview adding information tooltip
    (lp#561863).
  - Added tooltip for peeking quickly into categories.
  - Added preview for Audio items.
  - Added appindicator/Tray icon support.
  - Added support for Xchat.
  - Added support for Bazaar version control system.
  + Eye candy tweaks:
  - Added "welcome screen" showed when the Activity Journal
    starts and loads the items.
  - Go to Today button always highlighted.
  - Path's label clickable in MoreInformation window (lp#532303).
  - Usability tweaks to the views toolbar.
  - Item's categories becomes coloured when containing a searched
    item.
  + Bug fixes:
  - Fixed bookmark/pinning feature (lp#680653).
  - Fixed support for RECEIVE_EVENT (lp#667870).
  - Fixed day's part timerange (lp#655045).
  - Fixed crash caused by gstreamer (lp#705545).
  - Fixed problem with dialog windows (lp#706543).
  - Fixed title of MoreInformation window(lp#706544).
  - Fixed video previews problem.
  - Fixed visualization bug in TimeLineView.
  - Fixed internationalization and localization problems.
  + Misc:
  - Added support for DELETE_EVENT (fx. deleted Tomboy's notes
    aren't showed).
  - Cleaned up code (fixed some gtk and gio warnings, remove
    unused code).
  - Updated translations.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Dec 14 2010 vuntz@opensuse.org
- Add zeitgeist BuildRequires (which is already a Requires), for
  directory ownership, to fix build.
* Sun Sep 19 2010 vuntz@opensuse.org
- Update to version 0.5.0.1:
  + Updated Hamster-specific code to use the new ontology from
    Zeitgeist 0.5.0 (lp#641148, deb#591267).
  + Catch exception trying to extract a non-existant thumbnail from
    an OpenDocument file (lp#535440).
  + Fixed a possible issue with "%%20" being used in filenames.
  + Some minor changes (relabeled "Goto Today" to "Go to Today",
    added missing tooltips to toolbar icons).
  + Removed superfluous debugging (timing) information.
  + Removed Zeitgeist version check for Zeitgeist 0.5.0
    compatibility (as it reports a wrong version number).
  + Updated translations.
* Sun Sep 12 2010 vuntz@opensuse.org
- Update to tarball 0.5.0+tb1: this is the same tarball as 0.5.0,
  but it also contains the COPYING file. We don't change the
  version of the package, though, since except for this change,
  this is the exact same tarball.
- Change license from GPLv2+ to "GPLv3+ ; CC-BY-SA", as described
  in README.
- Ship COPYING in the package too.
- Fix bnc#599602.
* Tue Aug 24 2010 dimstar@opensuse.org
- Update to version 0.5.0:
  + Speed up startup by delaying stuff into gobject.idle_add.
  + Enable tooltips
  + Updated translations
* Mon May 10 2010 dimstar@opensuse.org
- Update to version 0.3.4.1:
  + Fixed bugs which arrived when using python 2.5
- Changes from version 0.3.4:
  + Core:
  - Added a content object system which allows users to launch,
    view, and manipulate events with non-file subjects.
  - Improved event request, and related event results.
  + Widgets:
  - New timeline view that now based on a gtktreeview.
  - Revamped multiple day view
  - Better support for Dark themes
  - Widgets using themes with pixbuf backgrounds are now drawn
    correctly
  - Added a More Information window which displays a description
    of the event, its subject, and other events related to the
    event.
  - Context menu now works in all widgets
  - Improved rendering in thumbnail view.
- Drop gnome-activity-journal-fix-install.patch, fixed differently
  by upstream.
* Sun Feb 21 2010 vuntz@opensuse.org
- Update to version 0.3.3:
  + New features, including:
  - "Detailed Day View" accessible over left clicking the day
    label.
  - "Thumbnail View" accessible over right clicking the day
    label.
  - Remove Items from the Journal
  + Performance improvements.
  + Many bug fixes.
- Update gnome-activity-journal-fix-install.patch for lp#525391.
* Thu Feb 11 2010 vuntz@opensuse.org
- Update gnome-activity-journal-fix-install.patch to fix another
  link.
* Sun Feb  7 2010 awafaa@opensuse.org
- New package, based on the old gnome-zeitgeist package.
